from typing import TypedDict, Optional, Any


class UploadedFile(TypedDict):
    """
- Contains data about a file uploaded using [_input_file_](../ppa.ui/#input_file)

!!! info "All UploadedFile Keys"

    __data__: File contents.

    __filename__: Original filename.

    __size__: Size of the file in bytes.

    __type__: Content type (if the browser was able to detect it).
    """

    data: str
    filename: str
    size: int
    type: str


class PayloadKey(TypedDict):
    """
- Describes a key to get from the task payload

!!! info "All PayloadKey Keys"

    __name__: The name of the key in the payload.

    __default_value__: An optional default value to use if the key is missing from the payload.
    """

    name: str
    default_value: Optional[Any] = None


class TimeStamp(TypedDict):
    """
- Contains submitted date picker information

!!! info "All TimeStamp Keys"

    __day__: The selected day.

    __month__: The selected month.

    __year__: The selected year.

    __hour__: The selected hour.

    __minute__: The selected minute.

    __second__: The submitted second.

    __timezone__: The chosen timezone.

    __timestamp__: The supplied date & time in `hh/mm/ss dd/mm/yyyy` format.
    """

    hour: int
    minute: int
    second: int
    day: int
    month: int
    year: int
    timezone: str
    timestamp: str
